@@ -24,6 +24,7 @@ import _ast
 try:
     import pep8
     HAS_PEP8 = True
+    PEP8_VERSION = tuple([int(x) for x in pep8.__version__.split('.')])
 except ImportError:
     HAS_PEP8 = False
 
@@ -46,7 +47,7 @@ def pep8_checker(pep8_options):
     extra_args = []
     for key, value in pep8_options.iteritems():
         value_spec = ','.join([ign.strip(', ') for ign in value.split()
-                              if ign.strip(', ')])
+                               if ign.strip(', ')])
         extra_args.append('--%s=%s' % (key, value_spec))
 
     def check_pep8(files_to_check, msg):
@@ -56,15 +57,25 @@ def pep8_checker(pep8_options):
                 os.makedirs(parentdir)
             open(filename, 'w').write(data)
 
-        # monkey patch sys.argv options so we can call pep8
-        old_args = sys.argv
-        sys.argv = ['pep8'] + files_to_check.keys() + extra_args
-        options, args = pep8.process_options()
-        sys.argv = old_args
-        for path in args:
-            pep8.input_file(path)
+        if PEP8_VERSION > (1, 2):
+            args = files_to_check.keys() + extra_args
+            options, paths = pep8.process_options(args)
+            options_dict = options.__dict__.copy()
+            options_dict['paths'] = paths
+            style_guide = pep8.StyleGuide(**options_dict)
+            report = style_guide.check_files()
+            return report.total_errors
 
-        return pep8.get_count()
+        else:
+            # monkey patch sys.argv options so we can call pep8
+            old_args = sys.argv
+            sys.argv = ['pep8'] + files_to_check.keys() + extra_args
+            options, args = pep8.process_options()
+            sys.argv = old_args
+            for path in args:
+                pep8.input_file(path)
+
+            return pep8.get_count()
 
     return check_pep8
 
@@ -79,7 +90,7 @@ def pep8hook(ui, repo, hooktype, node, pending, **kwargs):
     for opt in options:
         if ui.config('pep8', opt, ''):
             pep8_options[opt] = ui.config('pep8', opt, '')
-            
+
     checker_manager = CheckerManager(ui, repo, node, 'no-pep8')
     return checker_manager.check(pep8_checker(pep8_options))
 
